@@ -1,17 +1,15 @@
 from .base_column_profilers import BaseColumnProfiler
-from .numerical_column_stats import NumericStatsMixin
-from .datetime_column_profile import DateTimeColumn
-from .int_column_profile import IntColumn
-from .float_column_profile import FloatColumn
-from .text_column_profile import TextColumn
-
 from .categorical_column_profile import CategoricalColumn
-from .order_column_profile import OrderColumn
-
 from .data_labeler_column_profile import DataLabelerColumn
+from .datetime_column_profile import DateTimeColumn
+from .float_column_profile import FloatColumn
+from .int_column_profile import IntColumn
+from .numerical_column_stats import NumericStatsMixin
+from .order_column_profile import OrderColumn
+from .profile_builder import Profiler, StructuredProfiler, UnstructuredProfiler
+from .text_column_profile import TextColumn
 from .unstructured_labeler_profile import UnstructuredLabelerProfile
 
-from .profile_builder import StructuredProfiler, UnstructuredProfiler, Profiler
 """
 The purpose of this package is to provide statistics and predictions for a 
 given dataset.
