@@ -38,11 +38,23 @@ class BaseCompiler(with_metaclass(abc.ABCMeta, object)):
             self.name = df_series.name
             self._create_profile(df_series, options, pool)
 
-    @property
     @abc.abstractmethod
-    def profile(self):
+    def report(self, remove_disabled_flag=False):
+        """
+        Abstract method for returning report.
+
+        :param remove_disabled_flag: flag to determine if disabled options should be excluded in the report.
+        :type remove_disabled_flag: boolean
+        """
         raise NotImplementedError()
 
+    @property
+    def profile(self):
+        """
+        Property for profile. Returns the profile of the column.
+        """
+        return self.report(remove_disabled_flag=False)
+
     def _create_profile(self, df_series, options=None, pool=None):
         """
         Initializes and evaluates all profilers for the given dataframe.
@@ -194,8 +206,13 @@ class ColumnPrimitiveTypeProfileCompiler(BaseCompiler):
     ]
     _option_class = StructuredOptions
 
-    @property
-    def profile(self):
+    def report(self, remove_disabled_flag=False):
+        """
+        Method for returning report.
+
+        :param remove_disabled_flag: flag to determine if disabled options should be excluded in the report.
+        :type remove_disabled_flag: boolean
+        """
         profile = {
             "data_type_representation": dict(),
             "data_type": None,
@@ -207,7 +224,7 @@ class ColumnPrimitiveTypeProfileCompiler(BaseCompiler):
             if not has_found_match and profiler.data_type_ratio == 1.0:
                 profile.update({
                     "data_type": profiler.type,
-                    "statistics": profiler.profile,
+                    "statistics": profiler.report(remove_disabled_flag),
                 })
                 has_found_match = True
             profile["data_type_representation"].update(
@@ -215,6 +232,13 @@ class ColumnPrimitiveTypeProfileCompiler(BaseCompiler):
             )
         return profile
 
+    @property
+    def profile(self):
+        """
+        Property for profile. Returns the profile of the column.
+        """
+        return self.report(remove_disabled_flag=False)
+
     @property
     def selected_data_type(self):
         """
@@ -287,12 +311,17 @@ class ColumnStatsProfileCompiler(BaseCompiler):
     ]
     _option_class = StructuredOptions
 
-    @property
-    def profile(self):
-        profile = dict()
+    def report(self, remove_disabled_flag=False):
+        """
+        Method for returning report.
+
+        :param remove_disabled_flag: flag to determine if disabled options should be excluded in the report.
+        :type remove_disabled_flag: boolean
+        """
+        report = dict()
         for _, profiler in self._profiles.items():
-            profile.update(profiler.profile)
-        return profile
+            report.update(profiler.report(remove_disabled_flag))
+        return report
 
     def diff(self, other, options=None):
         """
@@ -325,18 +354,23 @@ class ColumnDataLabelerCompiler(BaseCompiler):
     ]
     _option_class = StructuredOptions
 
-    @property
-    def profile(self):
-        profile = {
+    def report(self, remove_disabled_flag=False):
+        """
+        Method for returning report.
+
+        :param remove_disabled_flag: flag to determine if disabled options should be excluded in the report.
+        :type remove_disabled_flag: boolean
+        """
+        report = {
             "data_label": None,
             "statistics": dict()
         }
         # TODO: Only works for last profiler. Abstracted for now.
         for _, profiler in self._profiles.items():
-            col_profile = profiler.profile
-            profile["data_label"] = col_profile.pop("data_label")
-            profile["statistics"].update(col_profile)
-        return profile
+            col_profile = profiler.report(remove_disabled_flag)
+            report["data_label"] = col_profile.pop("data_label")
+            report["statistics"].update(col_profile)
+        return report
     
     def diff(self, other, options=None):
         """
@@ -376,18 +410,20 @@ class UnstructuredCompiler(BaseCompiler):
 
     _option_class = UnstructuredOptions
 
-    @property
-    def profile(self):
+    def report(self, remove_disabled_flag=False):
+        """Report on profile attribute of the class and pop value
+            from self.profile if key not in self.__calculations
+        """
         profile = {
             "data_label": dict(),
             "statistics": dict()
         }
         if UnstructuredLabelerProfile.type in self._profiles:
             profile["data_label"] = \
-                self._profiles[UnstructuredLabelerProfile.type].profile
+                self._profiles[UnstructuredLabelerProfile.type].report(remove_disabled_flag)
         if TextProfiler.type in self._profiles:
             profile["statistics"] = \
-                self._profiles[TextProfiler.type].profile
+                self._profiles[TextProfiler.type].report(remove_disabled_flag)
         return profile
 
     def diff(self, other, options=None):
