@@ -239,6 +239,16 @@ class DataLabelerColumn(BaseColumnProfiler):
         }
         return profile
 
+    def report(self, remove_disabled_flag=False):
+        """
+        Private abstract method for returning report.
+
+        :param remove_disabled_flag: flag to determine if disabled
+            options should be excluded in the report.
+        :type remove_disabled_flag: boolean
+        """
+        return self.profile
+
     def diff(self, other_profile, options=None):
         """
         Generates the differences between the orders of two DataLabeler columns
