@@ -152,7 +152,7 @@ class TestBaseColumnPrimitiveTypeProfileClass(unittest.TestCase):
             BaseColumnPrimitiveTypeProfiler()
         self.assertEqual(
             "Can't instantiate abstract class BaseColumnPrimitiveTypeProfiler "
-            "with abstract methods _update_helper, profile, update",
+            "with abstract methods _update_helper, profile, report, update",
             str(e.exception)
         )
 
@@ -181,7 +181,7 @@ class TestBaseColumnPrimitiveTypeProfileClass(unittest.TestCase):
     def test_update_match_are_abstract(self):
         six.assertCountEqual(
             self,
-            {'_update_helper', 'update', 'profile'},
+            {'_update_helper', 'update', 'report', 'profile'},
             BaseColumnPrimitiveTypeProfiler.__abstractmethods__
         )
 
@@ -257,6 +257,10 @@ class AbstractTestColumnProfiler(object):
                 "data type": profiler.type,
                 "statistics": dict()
             }
+            mock_object.return_value.report.return_value = {
+                "data type": profiler.type,
+                "statistics": dict()
+            }
             mock_object.return_value.data_type_ratio = 1.0
             profiler_mocks.append(mock_object)
         self.column_profiler._profilers = profiler_mocks
@@ -284,6 +288,16 @@ class AbstractTestColumnProfiler(object):
             self.assertEqual(1, profiler_mock.call_count)
         self._delete_profiler_mocks()
 
+    def test_report(self):
+        self._create_profiler_mocks()
+        profile = self.column_profiler(self.aws_dataset["datetime"])
+
+        report1 = profile.profile
+        report2 = profile.report(remove_disabled_flag=False)
+        report3 = profile.report(remove_disabled_flag=True)
+        self.assertDictEqual(report1, report2)
+        self.assertDictEqual(report1, report3)
+
     def test_profile(self):
         self._create_profiler_mocks()
         profile = self.column_profiler(self.aws_dataset["datetime"])
